Numina User Guide — Numina 0.20.dev0 documentation

# Numina User Guide

This is Numina, the data reduction package used by the following GTC instruments: EMIR, MEGARA and FRIDA.

Numina is distributed under GNU GPL, either version 3 of the License, or (at your option) any later version. See the file LICENSE.txt for details.

This guide is intended as an introductory overview of Numina and explains how to install and make use of the most important features. For detailed reference documentation of the functions and classes contained in the package, see the Numina Reference.

Warning

This “User Guide” is still a work in progress; some of the material is not organized, and several aspects of Numina are not yet covered sufficient detail.

- Installation
  - Requirements
  - Installing numina
  - Building from source
  - Building the documentation
- Numina Deployment with Virtualenv
  - Install Virtualenv
  - Create Virtual Environment
  - Activate the Environment
  - Numina Installation
- Command Line Interface
  - Options for run
  - Options for show-instruments
  - Options for show-modes
  - Options for show-recipes